 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*---Creates all data sets as permanent SAS data sets and in *.xls format--*/
 /*---If the &permdir macro variable is not defined, the directory defined--*/
 /*---as &datadir is used. See the RunThisFirst.sas program for the assign- -*/
 /*---ment to &datadir.                                                   ---*/

%let permdir=;

%macro outdir;
%if %length(&permdir) %then %do;
   libname outdir "&permdir";
%end; %else %do;
   libname outdir "&datadir";
   %let permdir=&datadir;
%end;
%mend outdir;

%outdir;

%include "&progdir\CNRatioData.sas";
data outdir.CNRatio; set CNRatio; run;
proc export data=CNRatio
            outfile = "&permdir\CNRatio.xls" 
            dbms=EXCEL2000 replace;
run;


%include "&progdir\VABloodLeadLevelsData.sas";
data outdir.VA2000; set VA2000; run;
proc export data=VA2000
            outfile = "&permdir\VA2000.xls" 
            dbms=EXCEL2000 replace;
run;

%include "&progdir\WoodpeckerData.sas";
data outdir.wp_quads; set wp_quads; run;
proc export data=wp_quads
            outfile = "&permdir\wp_quads.xls" 
            dbms=EXCEL2000 replace;
run;

%include "&progdir\SimulatedPatternsData.sas";
data outdir.sim_pp; set sim_pp; run;
proc export data=Sim_pp
            outfile = "&permdir\Sim_pp.xls" 
            dbms=EXCEL2000 replace;
run;

%include "&progdir\RainFallData.sas";
data outdir.rainfall; set rainfall; run;
proc export data=rainfall
            outfile = "&permdir\Rainfall.xls" 
            dbms=EXCEL2000 replace;
run;


proc sim2d outsim=example_5_6;
   grid x=1 to 20 by 1
        y=1 to 20 by 1;
   simulate numreal=1 form=exponential range=3 nugget=0.25 
            scale=0.5 seed=34585;
run;
data outdir.example_5_6; set example_5_6; run;
proc export data=example_5_6
            outfile = "&permdir\Example_5_6.xls" 
            dbms=EXCEL2000 replace;
run;

%include "&progdir\DataforProblem5.13(the missing one).sas";
data outdir.problem5_13; set problem5_13; run;
proc export data=problem5_13
            outfile = "&permdir\Problem5_13.xls" 
            dbms=EXCEL2000 replace;
run;

