
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/
%include "&progdir\CNRatioData.sas";

 /*--------------------------------------------------------------*/
 /*---Testing the significance of the nugget effect with MIXED---*/
 /*---The results are reported in the first paragraph of p.177---*/
 /*--------------------------------------------------------------*/

 /*---Obtain the -2 restricted log likelihood of the nugget model-*/
proc mixed data=cnratio;
  model cn = / s;
  repeated / subject=intercept type=sp(exp)(x y) local;
  ods output FitStatistics=fit_nugget;
run;

 /*---Obtain the -2 restricted log likelihood of the no-nugget model*/
proc mixed data=cnratio;
  model cn = / s;
  repeated / subject=intercept type=sp(exp)(x y);
  ods output FitStatistics=fit_nonugget;
run;

data lrtest; 
   merge fit_nugget(where=(Descr='-2 Res Log Likelihood')
                         rename=(Value=M2REML_nugg))
         fit_nonugget(where=(Descr='-2 Res Log Likelihood')
                      rename=(Value=M2REML_nonugg));
   lrstat = M2Reml_nonugg - M2Reml_nugg;
   p = 1-ProbChi(lrstat,1);
   drop Descr;
run;
proc print data=lrtest label noobs;
  label p             = 'p-value'
        lrstat        = 'LRT Test Statistic'
		M2Reml_Nugg   = '-2 Res Log Like Nugget Model'
		M2Reml_NoNugg = '-2 Res Log Like No Nugget Model';
  format p pvalue6. M2Reml: d9.5;
run;
