 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

%include "&progdir\CNRatioData.sas";

 /*--------------------------------------------------------------*/
 /*---Examine anisotropy in CN semivariogram                  ---*/
 /*--------------------------------------------------------------*/

  /*---Compute directional semivariograms---*/
proc variogram data=cnratio outvar=svar;
   compute lagdistance=6 maxlag=35;
   coordinates xcoord=x ycoord=y;
   directions 0(22.5) 45(22.5) 90(22.5) 135(22.5);
   var cn;
run;
proc print data=svar; run;

 /*------------------------------------------------------*/
 /*---This template code is specific for SAS 9.1      ---*/
 /*---ODS graphics are experimental in SAS 9.1 and the---*/
 /*---template syntax is different in subsequent releases*/ 
 /*------------------------------------------------------*/
proc template;
  define statgraph svarpanel;
  layout lattice / rows=2 columns=2;
    /*---the first semivariogram---*/
    layout lattice / rows=1 columns=1;
         sidebar / align=top;                                                 
            layout overlay / padbottom=5;                                     
               entrytitle "0 +/- 22.5 degrees";                         
            endlayout;                                                        
         endsidebar;
         scatterplot y=variog0 x=distance0 / 
		             yaxisopts=(ticks=(0.2 0.4))
                     markersymbol=circleFilled;		             
	endlayout;
    /*---the second semivariogram---*/
    layout lattice / rows=1 columns=1;
         sidebar / align=top;                                                 
            layout overlay / padbottom=5;                                     
               entrytitle "45 +/- 22.5 degrees";                         
            endlayout;                                                        
         endsidebar;
         scatterplot y=variog1 x=distance1 /
		             yaxisopts=(ticks=(0.2 0.4))
                     markersymbol=circleFilled;		              
	endlayout;
    /*---the third semivariogram---*/
    layout lattice / rows=1 columns=1;
         sidebar / align=top;                                                 
            layout overlay / padbottom=5;                                     
               entrytitle "90 +/- 22.5 degrees";                         
            endlayout;                                                        
         endsidebar;
         scatterplot y=variog2 x=distance2 /
		             yaxisopts=(ticks=(0.2 0.4))
                     markersymbol=circleFilled;		             
	endlayout;
    /*---the fourth semivariogram---*/
    layout lattice / rows=1 columns=1;
         sidebar / align=top;                                                 
            layout overlay / padbottom=5;                                     
               entrytitle "135 +/- 22.5 degrees";                         
            endlayout;                                                        
         endsidebar;
         scatterplot y=variog3 x=distance3 / 
		             yaxisopts=(ticks=(0.2 0.4))
                     markersymbol=circleFilled;		             
	endlayout;
  endlayout;
  end;
run;

data graphThis;
   label distance0='Distance'
   	     distance1='Distance'
		 distance2='Distance'
		 distance3='Distance'
         variog0='Semivariance'
		 variog1='Semivariance'
		 variog2='Semivariance'
		 variog3='Semivariance';
   merge svar(where=(angle=0  ) rename=(distance=distance0 variog=variog0))
         svar(where=(angle=45 ) rename=(distance=distance1 variog=variog1))
         svar(where=(angle=90 ) rename=(distance=distance2 variog=variog2))
         svar(where=(angle=135) rename=(distance=distance3 variog=variog3));
    keep distance: variog:;
run;

ods html;
data _null_;
  set graphThis(where=(distance0 ne .));
  file print ods=(template="SvarPanel");
  put _ods_;
run;
ods html close;
