
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

%include "&progdir\CNRatioData.sas";

 /*---------------------------------------------*/
 /*---Nonparametric fitting of semivariograms---*/
 /*---Figures 4.12 and 4.13, p. 187, 188     ---*/
 /*---------------------------------------------*/

/*---First, get the empirical semivariogram ---*/
proc variogram data=cnratio 
               outvar=svar(where=(distance ne .));
  compute lagdistance=6 maxlag=35;
  coordinates xcoord=x ycoord=y;
  var cn;
run;

%let npoints=101;
%let omlimit=1;
data omega;
  array ome{&npoints.} o1-o&npoints.;
  do i = 1 to &npoints.; ome{i}=&omlimit. * (i-1)/(&npoints.-1); end;
  output;
  drop i;
run;
data filler; do distance=0 to 210 by 2; variog=.; filler=1; output; end;
data fitthis; set svar filler; 
data fitthis; set fitthis; if _n_ = 1 then set omega; run;

 /* use same nugget estimate as for moving average svar */
%let c0 = 0.116958;

 /*-------------------------------------------------------*/
 /*---A uniform kernel starting at 0                   ---*/
 /*---Only one parameter in the kernel function        ---*/
 /*-------------------------------------------------------*/
ods listing close;
proc nlmixed data=fitthis; 
  parms partialsill=0.16,ulparm=0 ,s=0.1;

  array omega{&npoints.} o1-o&npoints.;
  array integrand{&npoints.};

  ulimit = 1/(1+exp(-ulparm));
  
  /* fill the array with Omega(h\omega)f(\btheta,\omega) */
  do i = 1 to &npoints.;
    o = omega{i};
    if (o < 0) or (o > ulimit) then integrand{i} = 0;
    else integrand{i} = (1/ulimit)*JBessel(0,distance*o);
  end;
  /* approximate the integrals for C(h) */
  do i = 1 to &npoints.;
    if i = 1 then do;
      even = 0;
      Ch   = integrand{i}; 
    end; else if (i=&npoints.) then do;
      Ch = Ch + integrand{i};
    end; else if (even=0) then do;
      Ch = Ch + 2*integrand{i};
      even  = 1;
    end; else if (even=1) then do;
      Ch = Ch + 4*integrand{i};
      even  = 0;
    end;
  end;
  Ch = (&omlimit./&npoints.)*Ch/3;

  /* construct the semivariogram */
  svariogram = &c0 + partialsill*(1-Ch);
  model variog ~ normal(svariogram,s*s);
  estimate 'Upper Limit' ulimit;
  predict svariogram out=predicted;
  ods output ParameterEstimates=ests;
run;
ods listing;

data predicted; set predicted; 
  drop o1-o&npoints. stderrpred alpha probt df tvalue lower upper;
  where variog = .;
  rename distance=h;
  keep distance pred;
run;

data __plotthis_4_12_b1;
    merge predicted
    svar(keep=distance variog);
run;

goptions hsize=9in vsize=8in;
symbol1 color=black value=dot  height=0.175in;
symbol2 color=black value=none i=join l=1 w=2;
axis1 minor=none
      order=(0.0,0.05,0.1,0.15,0.2,0.25,0.3,0.35)
	  label=(font='Arial' Height=1.5 angle=90 'Semivariance')
      offset=(0in,0.5in)
	  value=(font='Arial' Height=1.3);
axis2 minor=none
      order=(0,50,100,150,200,250)
	  label=(font='Arial' Height=1.5 'Distance')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);
/*
title;
proc gplot data=__plotthis_4_12_b1;
   plot variog*distance = 1
        pred*h          = 2 / overlay 
                              vaxis=axis1 
                              haxis=axis2
		                      noframe;
run; quit;
*/ 
 /*-------------------------------------------------------*/
 /*---A uniform kernel starting at 0                   ---*/
 /*---Upper integration limit set to 2                 ---*/
 /*-------------------------------------------------------*/
%let npoints=101;
%let omlimit=2;
data omega;
  array ome{&npoints.} o1-o&npoints.;
  do i = 1 to &npoints.; ome{i}=&omlimit. * (i-1)/(&npoints.-1); end;
  output;
  drop i;
run;
data filler; do distance=0 to 210 by 2; variog=.; filler=1; output; end;
data fitthis; set svar filler; 
data fitthis; set fitthis; if _n_ = 1 then set omega; run;

/* use same nugget estimate as for moving average svar */
%let c0 = 0.116958;
ods listing close;
proc nlmixed data=fitthis; 
  parms partialsill=0.16,ulparm=0 ,s=0.1;

  array omega{&npoints.} o1-o&npoints.;
  array integrand{&npoints.};

  ulimit = &omlimit./(1+exp(-ulparm));
  
  /* fill the array with Omega(h\omega)f(\btheta,\omega) */
  do i = 1 to &npoints.;
    o = omega{i};
    if (o < 0) or (o > ulimit) then integrand{i} = 0;
    else integrand{i} = (1/ulimit)*JBessel(0,distance*o);
  end;
  /* approximate the integrals for C(h) */
  do i = 1 to &npoints.;
    if i = 1 then do;
      even = 0;
      Ch   = integrand{i}; 
    end; else if (i=&npoints.) then do;
      Ch = Ch + integrand{i};
    end; else if (even=0) then do;
      Ch = Ch + 2*integrand{i};
      even  = 1;
    end; else if (even=1) then do;
      Ch = Ch + 4*integrand{i};
      even  = 0;
    end;
  end;
  Ch = (&omlimit./&npoints.)*Ch/3;

  /* construct the semivariogram */
  svariogram = &c0 + partialsill*(1-Ch);
  model variog ~ normal(svariogram,s*s);
  estimate 'Upper Limit' ulimit;
  predict svariogram out=predicted;
  ods output ParameterEstimates=ests;
run;
ods listing;

data predicted; set predicted; 
  drop o1-o&npoints. stderrpred alpha probt df tvalue lower upper;
  where variog = .;
  rename distance=h2 pred=pred2;
  keep distance pred;
run;
/*
title;
data __plotthis_4_12_b2;
    merge predicted
    svar(keep=distance variog);
run;
proc gplot data=__plotthis_4_12_b2;
   plot variog*distance = 1
        pred2*h2        = 2 / overlay 
                              vaxis=axis1
							  haxis=axis2
							  noframe;
run; quit;
*/
 /*----------------------------------------------*/
 /*--- Plot both estimators in the same graph ---*/
 /*--- as in Figure 4.12, page 187            ---*/
symbol3 color=black value=none i=join l=20 w=2;
legend1 across=1 
        cborder=black
		mode=protect
        position=(bottom right inside)
		label=none
		value=(font='Arial Black' Height=1.2
		       'Empirical'
               'b=1'
			   'b=2');

data __plotthis_4_12;
   merge __plotthis_4_12_b1 __plotthis_4_12_b2;
run;
proc gplot data=__plotthis_4_12;
   plot variog *distance  = 1
        pred*h            = 2
        pred2*h2          = 3 / overlay
                                vaxis=axis1
							    haxis=axis2
								legend=legend1
							    noframe;
run; quit;
 /*----------------------------------------------*/




 /*-------------------------------------------------------*/
 /*---A uniform kernel starting at 0                   ---*/
 /*---Nugget effect is estimated                       ---*/
 /*---Only one parameter in the kernel function        ---*/
 /*-------------------------------------------------------*/
proc variogram data=cnratio outvar=svar;
  compute lagdistance=6 maxlag=35;
  coordinates xcoord=x ycoord=y;
  var cn;
run;
data svar; set svar(where=(distance ne .)); run;

%let npoints=101;
%let omlimit=1;
data omega;
  array ome{&npoints.} o1-o&npoints.;
  do i = 1 to &npoints.; ome{i}=&omlimit. * (i-1)/(&npoints.-1); end;
  output;
  drop i;
run;
data filler; do distance=0 to 210 by 2; variog=.; filler=1; output; end;
data fitthis; set svar filler; 
data fitthis; set fitthis; if _n_ = 1 then set omega; run;
ods listing close;
proc nlmixed data=fitthis; 
  parms partialsill=0.16,ulparm=0,c0=0.11 ,s=0.1;
  bounds c0 >= 0;
  array omega{&npoints.} o1-o&npoints.;
  array integrand{&npoints.};

  ulimit = 1/(1+exp(-ulparm));
  
  /* fill the array with Omega(h\omega)f(\btheta,\omega) */
  do i = 1 to &npoints.;
    o = omega{i};
    if (o < 0) or (o > ulimit) then integrand{i} = 0;
    else integrand{i} = (1/ulimit)*JBessel(0,distance*o);
  end;
  /* approximate the integrals for C(h) */
  do i = 1 to &npoints.;
    if i = 1 then do;
      even = 0;
      Ch   = integrand{i}; 
    end; else if (i=&npoints.) then do;
      Ch = Ch + integrand{i};
    end; else if (even=0) then do;
      Ch = Ch + 2*integrand{i};
      even  = 1;
    end; else if (even=1) then do;
      Ch = Ch + 4*integrand{i};
      even  = 0;
    end;
  end;
  Ch = (&omlimit./&npoints.)*Ch/3;

  /* construct the semivariogram */
  svariogram = c0 + partialsill*(1-Ch);
  model variog ~ normal(svariogram,s*s);
  estimate 'Upper Limit' ulimit;
  predict svariogram out=predicted;
  ods output ParameterEstimates=ests;
run;
ods listing;

data predicted; set predicted; 
  drop o1-o&npoints. stderrpred alpha probt df tvalue lower upper;
  where variog = .;
  rename distance=h;
  keep distance pred;
run;

data __plotthis_4_13_b1;
    merge predicted
    svar(keep=distance variog);
run;

goptions hsize=9in vsize=8in;
symbol1 color=black value=dot  height=0.175in;
symbol2 color=black value=none i=join l=1 w=2;
axis1 minor=none
      order=(0.0,0.05,0.1,0.15,0.2,0.25,0.3,0.35)
	  label=(font='Arial' Height=1.5 angle=90 'Semivariance')
      offset=(0in,0.5in)
	  value=(font='Arial' Height=1.3);
axis2 minor=none
      order=(0,50,100,150,200,250)
	  label=(font='Arial' Height=1.5 'Distance')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);
/*
title;
proc gplot data=__plotthis_4_13_b1;
   plot variog*distance = 1
        pred*h          = 2 / overlay 
                              vaxis=axis1 
                              haxis=axis2
		                      noframe;
run; quit;
*/

/*-------------------------------------------------------*/
 /*---A uniform kernel starting at 0                   ---*/
 /*---Nugget effect is estimated                       ---*/
 /*---Upper limit of integration is 2                  ---*/
 /*-------------------------------------------------------*/

%let npoints=101;
%let omlimit=2;
data omega;
  array ome{&npoints.} o1-o&npoints.;
  do i = 1 to &npoints.; ome{i}=&omlimit. * (i-1)/(&npoints.-1); end;
  output;
  drop i;
run;
data filler; do distance=0 to 210 by 2; variog=.; filler=1; output; end;
data fitthis; set svar filler; 
data fitthis; set fitthis; if _n_ = 1 then set omega; run;
ods listing close;
proc nlmixed data=fitthis; 
  parms partialsill=0.16,ulparm=0,c0=0.11 ,s=0.1;
  bounds c0 >= 0;
  array omega{&npoints.} o1-o&npoints.;
  array integrand{&npoints.};

  ulimit = &omlimit./(1+exp(-ulparm));
  
  /* fill the array with Omega(h\omega)f(\btheta,\omega) */
  do i = 1 to &npoints.;
    o = omega{i};
    if (o < 0) or (o > ulimit) then integrand{i} = 0;
    else integrand{i} = (1/ulimit)*JBessel(0,distance*o);
  end;
  /* approximate the integrals for C(h) */
  do i = 1 to &npoints.;
    if i = 1 then do;
      even = 0;
      Ch   = integrand{i}; 
    end; else if (i=&npoints.) then do;
      Ch = Ch + integrand{i};
    end; else if (even=0) then do;
      Ch = Ch + 2*integrand{i};
      even  = 1;
    end; else if (even=1) then do;
      Ch = Ch + 4*integrand{i};
      even  = 0;
    end;
  end;
  Ch = (&omlimit./&npoints.)*Ch/3;

  /* construct the semivariogram */
  svariogram = c0 + partialsill*(1-Ch);
  model variog ~ normal(svariogram,s*s);
  estimate 'Upper Limit' ulimit;
  predict svariogram out=predicted;
  ods output ParameterEstimates=ests;
run;
ods listing;

data predicted; set predicted; 
  drop o1-o&npoints. stderrpred alpha probt df tvalue lower upper;
  where variog = .;
  rename distance=h2 pred=pred2;
  keep distance pred;
run;
/*
title;
data __plotthis_4_13_b2;
    merge predicted
    svar(keep=distance variog);
run;
proc gplot data=__plotthis_4_13_b2;
   plot variog*distance = 1
        pred2*h2        = 2 / overlay 
                              vaxis=axis1
							  haxis=axis2
							  noframe;
run; quit;
*/
 /*----------------------------------------------*/
 /*--- Plot both estimators in the same graph ---*/
 /*--- as in Figure 4.13, page 188            ---*/
symbol3 color=black value=none l=20 w=3;
legend1 across=1 
        cborder=black
		mode=protect
        position=(bottom right inside)
		label=none
		value=(font='Arial Black' Height=1.2
               'Empirical'
               'b=1'
			   'b=2');

data __plotthis_4_13;
   merge __plotthis_4_13_b1 __plotthis_4_13_b2;
run;
proc gplot data=__plotthis_4_13;
   plot variog *distance  = 1
        pred*h            = 2
        pred2*h2          = 3 / overlay
                                vaxis=axis1
							    haxis=axis2
								legend=legend1
							    noframe;
run; quit;
 /*----------------------------------------------*/
