
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*---Compute empirical semivariogram of C/N ratios (Matheron estimator)  --*/
 /*---Display semivariogram along with lag class counts                  ---*/

%include "&prodir\CNRatioData.sas";

proc variogram data=cnratio outvar=svar;
  compute lagdistance=6 maxlag=35;
  coordinates xcoord=x ycoord=y;
  var CN;
run;
data svar; set svar(where=(distance ne .));
data svar; set svar;
  length cntstr $3;
  odd = mod(_n_,2);
  if (odd) then pos2 = 0.4;
  else pos2 = 0.38;
  cntstr = left(put(count,3.));
run;
proc print data=svar; run;

goptions hsize=9in vsize=6in;

symbol1 color=black value=dot  height=0.175in;
symbol2 color=black value=none height=0.05in
        pointlabel=(font='Arial' j=c position=middle "#cntstr");

axis1 minor=none
      order=(0,0.1,0.2,0.3,0.4)
	  label=(font='Arial' Height=1.5 angle=90 'Semivariance')
      offset=(0in,0.5in)
	  value=(font='Arial' Height=1.3);
axis2 minor=none
      order=(0,50,100,150,200,250)
	  label=(font='Arial' Height=1.5 'Distance')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);

proc gplot data=svar;
   plot pos2  *distance=2 
        variog*distance=1 
        / overlay noframe vaxis=axis1 haxis=axis2;
run;
quit;
