

 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*--------------------------------------------------*/
 /*---Data for Table 3.3, page 97 and Moran's I   ---*/
 /*---analysis in Table 3.4                       ---*/
 /*--------------------------------------------------*/

data table33;
  input row col1-col10;
  datalines;
10  0  0  0  5  9  4  5 0 0 0 
 9  0  2  2  6  3  4  1 0 0 0
 8  0  0  6  3  3  0  1 0 2 2
 7  1  0  2  1  1  3  5 4 2 2 
 6  2  1  4 19 15 14  6 4 3 1
 5  3  4 17 42 41  8  9 5 1 0
 4  2 14 21 34 31 31 22 7 4 4
 3  5  5 11 25 31 45 33 3 0 1
 2  2  0  3  5  6 10 19 8 0 0
 1  0  0  3  5  0  3  2 2 0 0 
;
data tablong;
  set table33;
  array col{10};
  do column = 1 to 10; cnt=col{column}; output; end;
  drop col1-col10;
run;

 /*---Load the necessary macros to compute weights---*/
 /*---and to perform the Moran's I analysis       ---*/
%include "&macrodir\ContiguityWeightsMacro.sas";
%include "&macrodir\MoranIMacro.sas";
%include "&macrodir\GearycMacro.sas";

 /*---Run the macros                              ---*/
%ContWght(rows = 10   ,
          cols = 10   ,
          move = queen,
          out  = queen);

%MoranI(data   = tablong,
        y      = cnt    ,
        row    = row    ,
        col    = column ,
        w_data = queen  ,
        print  = 0      );

%Gearyc(data   = tablong,
        y      = cnt    ,
        row    = row    ,
        col    = column ,
        w_data = queen  ,
        print  = 0      );
run;

 /*---Collect the results and format              ---*/
data table3_4;
  set _moranI(rename=(Iobs=Obs EI=E StdI=Std pright=pval))
      _gearyc(rename=(Cobs=Obs EC=E StdC=Std));
  if _n_ <= 2 then Statistic='I'; else Statistic='c';
run;
title "Table 3.4, p. 97";
proc print data=table3_4 label noobs;
   label Assump    = 'Method' 
         Statistic = 'Statistic'
   	     Obs       = 'Observed Value' 
         E         = 'Expected Value'
         Std       = 'Standard Error'
         Pval      = 'P-Value';
	format Obs E Std 6.4 pval pvalue6.;
    var Assump Statistic Obs E Std pval;
run;
