
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*------------------------------------------------------*/
 /*---Example 5.11 Rainfall amounts (mm)              ---*/
 /*---Predictions of rainfall amounts by cross-validation*/
 /*---Table 5.4, page 277                             ---*/
 /*------------------------------------------------------*/

%include "&progdir\RainfallData.sas";
data rainfall; set rainfall;
  usey = rainfall;
run;

 /*---Load the cross-validation macro                 ---*/
%include "&macrodir\jcv.sas";

 /*------------------------------------------------------*/
 /*---Procduce the first and second rows of Table 5.4 ---*/
%jcvd(data=rainfall,var=usey);
run;

proc mixed data=dall;
   model usey = / solution ddfm=residual outp=pred1_exp;
   repeated / type=sp(pow)(x y) subject=intercept;
   parms (0 to 0.95 by 0.05) (200) / lowerb=0,. upperb=0.98,.;
   ods select ConvergenceStatus CovParms;
   by s;
run;
proc mixed data=dall;
   model usey = / solution ddfm=residual outp=pred1_sph;
   repeated / type=sp(sph)(x y) subject=intercept;
   parms (1 to 10 by 1) (225); 
   ods select ConvergenceStatus CovParms;
   by s;
run;

ods listing close;
proc mixed data=dall;
   model usey = / solution ddfm=kenwardroger outp=pred2_exp;
   repeated / type=sp(pow)(x y) subject=intercept;
   parms (0 to 0.95 by 0.05) (200) / lowerb=0,. upperb=0.98,.; 
   by s;
run;
proc mixed data=dall;
   model usey = / solution ddfm=kenwardroger outp=pred2_sph;
   repeated / type=sp(sph)(x y) subject=intercept;
   parms (1 to 10 by 1) (225); 
   by s;
run;
ods listing;
data pred1_exp; 
   set pred1_exp(where=(usey=.));
   stderr = stderrpred;
   zlower = pred-1.96*stderr;
   zupper = pred+1.96*stderr;
   tlower = pred-tinv(0.975,df)*stderr;
   tupper = pred+tinv(0.975,df)*stderr;
   keep x y rainfall pred stderr zlower zupper tlower tupper;
run;
data pred1_sph; 
   set pred1_sph(where=(usey=.));
   stderr = stderrpred;
   zlower = pred-1.96*stderr;
   zupper = pred+1.96*stderr;
   tlower = pred-tinv(0.975,df)*stderr;
   tupper = pred+tinv(0.975,df)*stderr;
   keep x y rainfall pred stderr zlower zupper tlower tupper;
run;

data pred2_exp;
   set pred2_exp(where=(usey=.));
   krstderr = stderrpred;
   krlower  = pred-tinv(0.975,df)*krstderr;
   krupper  = pred+tinv(0.975,df)*krstderr;
   keep x y rainfall krstderr krlower krupper df;
run;
data pred2_sph;
   set pred2_sph(where=(usey=.));
   krstderr = stderrpred;
   krlower  = pred-tinv(0.975,df)*krstderr;
   krupper  = pred+tinv(0.975,df)*krstderr;
   keep x y rainfall krstderr krlower krupper df;
run;

proc sort data=pred1_exp; by x y;
proc sort data=pred1_sph; by x y;
proc sort data=pred2_exp; by x y;
proc sort data=pred2_sph; by x y;
run;

 /*---Combine the data sets: OK(EXP)---*/
data comb_exp;
   merge pred1_exp pred2_exp;
   by x y;
   error     = pred-rainfall;
   relbias   = (error/rainfall)*100;
   absrelerr = (abs(error)/rainfall)*100;
   kradjpct  = ((krstderr-stderr))/stderr*100;
   zind  = 0;
   tind  = 0;
   krind = 0;
   if zlower  <= rainfall <= zupper  then zind  = 100;
   if tlower  <= rainfall <= tupper  then tind  = 100;
   if krlower <= rainfall <= krupper then krind = 100;
run;
 /*---Combine the data sets: OK(SPH)---*/
data comb_sph;
   merge pred1_sph pred2_sph;
   by x y;
   error     = pred-rainfall;
   relbias   = (error/rainfall)*100;
   absrelerr = (abs(error)/rainfall)*100;
   kradjpct  = ((krstderr-stderr))/stderr*100;
   zind  = 0;
   tind  = 0;
   krind = 0;
   if zlower  <= rainfall <= zupper  then zind  = 100;
   if tlower  <= rainfall <= tupper  then tind  = 100;
   if krlower <= rainfall <= krupper then krind = 100;
run;
proc means data=comb_exp noprint;
   var relbias absrelerr kradjpct zind;
   output out=ok_exp mean=relbias absrelerr kradjpct zind;
run;
proc means data=comb_sph noprint;
   var relbias absrelerr kradjpct zind;
   output out=ok_sph mean=relbias absrelerr kradjpct zind;
run;
data ok_exp; set ok_exp;
  length Method $13;
  Method = "OK (EXP)";
run;
data ok_sph; set ok_sph;
  length Method $13;
  Method = "OK (SPH)";
run;
 /*------------------------------------------------------*/


 /*-----------------------------------------------------*/
 /*---Procduce the third and fourth row of Table 5.4 ---*/

data rainfall; set rainfall;
  usey = boxcox;
run;
%jcvd(data=rainfall,var=usey);
run;

proc mixed data=dall;
   model usey = / solution ddfm=residual outp=pred1_tg_exp;
   repeated / type=sp(pow)(x y) subject=intercept;
   parms (0 to 0.95 by 0.05) (1);
   ods select ConvergenceStatus CovParms;
   ods output covparms  = cp
              solutionf = means;
   by s;
run;
ods listing close;
proc mixed data=dall;
   model usey = / ddfm=kenwardroger outp=pred2_tg_exp;
   repeated / type=sp(pow)(x y) subject=intercept;
   parms (0 to 0.95 by 0.05) (1); 
   by s;
run;
ods listing;

 /*---Compute the Lagrangian multipler                ---*/
proc iml; reset noprint fuzz=1e-20;
  use rainfall; read all var{x y} into s;  close rains;
  use cp;       read all var{estimate} into covparms;
                read all var{s}        into set;
  close cp;
  use means; read all var{estimate} into mu; close means;
  maxset = ncol(unique(set));
  lambda = &lambda.;
  /* build BigGamma */
  n = maxset;
  euclid = J(n,n,0);
  do i=1 to n;
    dist = sqrt((s[i,1] - s[,1])##2 + (s[i,2]-s[,2])##2);
	euclid[,i] = dist;
  end;
  /* cycle through the sets of covariance parameter estimates */
  m = J(n,4,.);
  onevec = J(n-1,1,1);
  ind = (1:n)`;
  do i = 1 to n;
    l = loc(set=i);
    cp = covparms[l];
    l  = loc(ind ^=i);
    BigGamma = cp[2]#(1- (cp[1]##(euclid[l,l])));
    /* li'l gamma for the ith observed point */
    dist = euclid[l,i];
    LilGamma = cp[2]#(1- (cp[1]##dist));
    /* Lagramge multiplier */
    m[i,1] = -(1 - onevec`*Inv(BigGamma)*Lilgamma)/(onevec`*Inv(BigGamma)*onevec);
    /*  GLS estimate of jack-knifed mean on Y scale*/
    m[i,2] = mu[i]; 
    /* @phi(mu)/@mu */
    m[i,3] = (lambda # mu[i] + 1)##(1/lambda-1); 
    /* @@phi(mu)/@mu/@mu */
    m[i,4] = (1/lambda-1)#lambda# ((lambda # mu[i] + 1)##(1/lambda-2));
  end;
  names = {"lagrang","mu_y","phiprime","phiprimeprime"};
  print m;
  create lagrang from m[colname=names];
  append from m;
quit;
proc print data=lagrang; run;

data pred1_; 
   merge pred1_tg_exp(where=(usey=.)) lagrang;
   pred_bias     = (&lambda*pred+1)**(1/&lambda.);
   pred_nobias   = pred_bias + 0.5*phiprimeprime*(stderrpred*stderrpred - 2*lagrang);
   stderr        = phiprime*stderrpred;
   zlower_bias   = pred_bias   - 1.96*stderr;
   zupper_bias   = pred_bias   + 1.96*stderr;
   zlower_nobias = pred_nobias - 1.96*stderr;
   zupper_nobias = pred_nobias + 1.96*stderr;
   tlower_bias   = pred_bias   - tinv(0.975,df)*stderr;
   tupper_bias   = pred_bias   + tinv(0.975,df)*stderr;
   tlower_nobias = pred_nobias - tinv(0.975,df)*stderr;
   tupper_nobias = pred_nobias + tinv(0.975,df)*stderr;
   keep x y rainfall stderr 
        pred_bias pred_nobias 
        zlower_bias zlower_nobias zupper_bias zupper_nobias
        tlower_bias tlower_nobias tupper_bias tupper_nobias;
run;

data pred2_; 
   merge pred2_tg_exp(where=(usey=.)) lagrang;
   krpred_bias    = (&lambda*pred+1)**(1/&lambda.);
   krpred_nobias  = krpred_bias + 0.5*phiprimeprime*(stderrpred*stderrpred - 2*lagrang);
   krstderr       = phiprime*stderrpred;
   krlower_bias   = krpred_bias-tinv(0.975,df)*krstderr;
   krupper_bias   = krpred_bias+tinv(0.975,df)*krstderr;
   krlower_nobias = krpred_nobias-tinv(0.975,df)*krstderr;
   krupper_nobias = krpred_nobias+tinv(0.975,df)*krstderr;
   keep x y rainfall krstderr 
        krpred_bias krpred_nobias 
        krlower_bias krlower_nobias krupper_bias krupper_nobias df;
run;

proc sort data=pred1_; by x y; run;
proc sort data=pred2_; by x y; run;

data comb; 
   merge pred1_ pred2_; by x y; 
   zind_bias    = 0;
   tind_bias    = 0;
   krind_bias   = 0;
   zind_nobias  = 0;
   tind_nobias  = 0;
   krind_nobias = 0;
   if zlower_bias    <= rainfall  <= zupper_bias    then zind_bias    = 100;
   if tlower_bias    <= rainfall  <= tupper_bias    then tind_bias    = 100;
   if krlower_bias   <= rainfall  <= krupper_bias   then krind_bias   = 100;
   if zlower_nobias  <= rainfall  <= zupper_nobias  then zind_nobias  = 100;
   if tlower_nobias  <= rainfall  <= tupper_nobias  then tind_nobias  = 100;
   if krlower_nobias <= rainfall  <= krupper_nobias then krind_nobias = 100;
    error_bias       = pred_bias-rainfall;
    relbias_bias     = (error_bias/rainfall)*100;
    absrelerr_bias   = (abs(error_bias)/rainfall)*100;
    error_nobias     = pred_nobias-rainfall;
    relbias_nobias   = (error_nobias/rainfall)*100;
    absrelerr_nobias = (abs(error_nobias)/rainfall)*100;
    differror        = error_nobias-error_bias;
    kradjpct         = ((krstderr-stderr))/stderr*100;
run;

proc means data=comb noprint;
   var relbias_nobias absrelerr_nobias kradjpct zind_nobias;
   output out=tg_nobias mean=relbias absrelerr kradjpct zind;
run;
proc means data=comb noprint;
   var relbias_bias absrelerr_bias kradjpct zind_bias;
   output out=tg_bias mean=relbias absrelerr kradjpct zind;
run;
data tg_bias; set tg_bias;
  length Method $13;
  Method = "TGK (no b.c.)";
run;
data tg_nobias; set tg_nobias;
  length Method $13;
  Method = "TGK (b.c.)";
run;
 /*-----------------------------------------------------*/


 /*-----------------------------------------------------*/
 /*---Procduce the last row of Table 5.4             ---*/
data rainfall; set rainfall;
  orignorms = normscore;
run;
%jcvd(data=rainfall,var=normscore);
run;

proc mixed data=dall;
   model normscore = / solution ddfm=residual outp=pred_ns;
   repeated / type=sp(pow)(x y) subject=intercept;
   parms (0 to 0.95 by 0.05) (2);
   by s;
   ods select ConvergenceStatus CovParms;
run;

proc sort data=pred_ns(where=(normscore=.))
          out=normscorsims;
     by rainfall;
run;

data normscorsims;
  set normscorsims(rename=(stderrpred=stderr));
  lowerbz  = pred-1.96*stderr;
  upperbz  = pred+1.96*stderr;
  obs      = _N_;
run;
proc sort data=normscorsims; by orignorms; run;

proc iml; 
  use normscorsims;
           read all var{orignorms} into z;
		   read all var{rainfall}  into y;
		   read all var{pred}      into pred;
		   read all var{lowerbz}   into lbz;
		   read all var{upperbz}   into ubz;
  close normscorsims;
  slopelow = y[2]-y[1];
  slopehi  = y[nrow(y)] - y[nrow(y)-1];
  n = nrow(z);

  start interp(whichvec,col) global(n,y,z,interpvals,slopelow,slopehi);
    minz = z[><];
	maxz = z[<>];
	miny = y[><];
	maxy = y[<>];
    do i=1 to n;
       found = 0;
	   k     = 1;
       do while ((found=0) & (k<=(n-1)));
	      if (whichvec[i] >= z[k]) & (whichvec[i]<z[k+1]) then do;
		     found = 1;
             interpvals[i,col] = (y[k+1]+y[k])/2;
		  end;
		  k = k + 1;
       end;
	   if (found=0) then do;
          if (whichvec[i] <= minz) then do;
               interpvals[i,col] = miny - (whichvec[i]-minz)*slopelow;
		  end; else if (whichvec[i] >= maxz) then do;
               interpvals[i,col] = maxy + (whichvec[i]-maxz)*slopehi;
		  end;
	   end;
    end;
  finish;

  /* --------------------------------------------------------------- */
  /* Use the min or max value as conf. limits that are out of bounds */
  /* interpolate the predicted values */
  interpvals = J(n,3,.);
  run interp(pred,1);
  /* interpolate the lower bounds values */
  run interp(lbz,2);
  /* interpolate the lower bounds values */
  run interp(ubz,3);
  names = {"ZPred_ip","ZLower_ip","ZUpper_ip"};
 * print interpvals[colname=names];
  /* ---------------------------------------------------------------- */
  create out from interpvals[colname=names];
  append from interpvals;
  close out;
quit;

data comb; 
  merge normscorsims out;
  zind = 0;
  if ZLower_ip <= rainfall <= ZUpper_ip then zind=100;
  error     = ZPred_ip-rainfall;
  relbias   = (error/rainfall)*100;
  absrelerr = (abs(error)/rainfall)*100;
run;

proc means data=comb noprint;
   var relbias absrelerr zind;
   output out=ns mean=relbias absrelerr zind;
run;
data ns; set ns;
  length Method $13;
  Method = "NS";
run;
 /*-----------------------------------------------------*/


 /*-----------------------------------------------------*/
 /*---Print the table                                ---*/
title "Table 5.4, page 277";
data table5_4; 
   set ok_exp 
       ok_sph
       tg_bias
	   tg_nobias
	   ns;
run;
proc print data=table5_4 noobs label;
  label Relbias   = 'Average Relative Bias'
        absrelerr = 'Average Absolute Error'
        kradjpct  = '% Increase in Std. Error'
        zind      = 'Gaussian 95% PI'; 
  format relbias absrelerr 6.2 kradjpct 4.2 zind 5.1;
  var Method relbias absrelerr kradjpct zind;
run;
 /*-----------------------------------------------------*/
