
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/


 /*-------------------------------------------------------------------------*/
 /*---Simulated point patterns for Chapter 3 (see Figure 3.1, p. 82)     ---*/
 /*---Coordinates csrx, csry: a CSR pattern                              ---*/
 /*---Coordinates clux, cluy: a clustered pattern                        ---*/
 /*---Coordinates regx, regy: a regular pattern                          ---*/
 /*-------------------------------------------------------------------------*/

%include "&progdir\SimulatedPatternsData.sas";

title;
goptions vsize=6 in hsize=6 in;
symbol1;
symbol1 color=black h=0.3in i=none value=circle;
axis1 order=(0 0.2 0.4 0.6 0.8 1.0)
      minor=none
	  label=none
      offset=(0.2in,0.2in)
	  value=(font='Arial' Height=1.3
             '0.0' '0.2' '0.4' '0.6' '0.8' '1.0');
proc gplot data=sim_pp;
   title 'a) Completely Random Pattern';
   plot csry*csrx=1 / vaxis=axis1 haxis=axis1; 
proc gplot data=sim_pp;
   title 'b) Poisson Cluster Process';
   plot cluy*clux=1 / vaxis=axis1 haxis=axis1; 
proc gplot data=sim_pp;
   title 'c) Sequential Inhibition';
   plot regy*regx=1 / vaxis=axis1 haxis=axis1;
run; quit;


 /*--------------------------------------------------*/
 /*---Table 3.1, p. 92                            ---*/
 /*--------------------------------------------------*/
%macro quads(data=sim_pp,y=csry,x=csrx,div=5);
  data _test; set &data;
     _xx = ceil(&x/(1/&div));
     _yy = ceil(&y/(1/&div));
  run;
  proc freq data=_test;
    tables _yy*_xx / norow nocol nopercent out=tabout;
  run;
  proc means data=tabout noprint; var count; output out=total sum=total; run;
  data tabout; set tabout end=last; if _n_ = 1 then merge total;
     retain ChiStat 0;
     nbar = total/_freq_;
     X2 = ((count - nbar)**2)/nbar;
     ChiStat+X2;
  run;
  proc means data=tabout noprint; var X2; output out=ChiStat sum=ChiStat; run;
  data Chistat; set Chistat;
    prleft = ProbChi(Chistat,_freq_-1);
  run;
  proc print data=Chistat; var ChiStat PrLeft; run;
%mend quads;

title1 'CSR Pattern';
%quads(data=sim_pp,y=csry,x=csrx,div=5);
title1 'Clustered Pattern';
%quads(data=sim_pp,y=cluy,x=clux,div=5);
title1 'Regular Pattern';
%quads(data=sim_pp,y=regy,x=regx,div=5);
