
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

%include "&progdir\CNRatioData.sas";

 /*------------------------------------------------------------*/
 /*---Example 6.1 Soil carbon regression. Figure 6.4, p. 314---*/
 /*---Semivariograms of random permutations of the input data--*/
 /*---set to demonstrate order dependence of recursive re-  ---*/
 /*---siduals.                                              ---*/
 /*------------------------------------------------------------*/

 /*---Randomly permute a data set &sim times and collect the --*/
 /*---results in data set WORK.PERMDATA.                    ---*/
%macro perm(sim=10,data=_last_,seed=4354);
  options nonotes;
  proc datasets lib=work memtype=data nolist; delete permdata one; run; quit;
  %do i=1 %to &sim;
     data one; set &data; r=ranuni(&seed); set=&i.; run;
	 proc sort data=one; by r;
	 proc datasets lib=work memtype=data nolist;
	   append base=permdata data=one force;
	 run; quit;
	 %let seed=%eval(&seed.+1);
  %end;
  proc sort data=permdata; by set; run;
  options notes;
%mend;

%perm(data=Cnratio(keep=x y tc tn));
 
 /*---Get recursive residuals with PROC AUTOREG---*/
 /*---using BY-processing.                     ---*/
ods listing close;
proc autoreg data=permdata;
  model tc = tn;
  output out=resids recres=recres;
  by set;
run;
ods listing;

%let lagd=6;
%let maxlag=44;
proc variogram data=resids(where=(recres ne .)) outvar=recsvar;
  compute lagdistance=&lagd. maxlag=&maxlag.;
  coordinates xcoord=x ycoord=y;
  var recres;
  by set;
run;

goptions hsize=8in vsize=6in;
symbol1 c=black i=join v=none r=10;
axis1 minor=none
      order=(0.0000,0.0005,0.0010,0.0015,0.0020)
	  label=(font='Arial' Height=1.5 angle=90 'Semivariance')
      offset=(0in,0.5in)
	  value=(font='Arial' Height=1.3);
axis2 minor=none
      order=(0,50,100,150,200,250,300)
	  label=(font='Arial' Height=1.5 'Distance')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);

proc gplot data=recsvar;
  plot variog*distance=set / noframe 
                             nolegend
                             vaxis=axis1 
                             haxis=axis2;
run;
quit;

