
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

%include "&progdir\CNRatioData.sas";

 /*---Example 6.1, Table 6.2, p. 346                                     ---*/
 /*---Fit spatial regression model for C/N data by OLS, REML, and ML     ---*/

title1 'Independence - REML';
proc glimmix data=cnratio;
  model TC = TN / s;
  ods select FitStatistics;
  ods output FitStatistics = ind_reml(where=(Descr='-2 Res Log Likelihood'));
run;

title1 'Independence - ML';
proc glimmix data=cnratio noreml;
  model TC = TN / s;
  ods select FitStatistics;
  ods output FitStatistics = ind_ml(where=(Descr='-2 Log Likelihood'));
run;

title1 'Exponential--REML Results';
proc glimmix data=cnratio;
  model TC = TN / s;
  random _residual_ / subject=intercept type=sp(exp)(x y);
  ods select FitStatistics;
  ods output FitStatistics = exp_reml(where=(Descr='-2 Res Log Likelihood'));
run;

title1 'Exponential--ML';
proc glimmix data=cnratio method=mspl;
  model TC = TN / s;
  random _residual_ / subject=intercept type=sp(exp)(x y);
  ods select FitStatistics;
  ods output FitStatistics = exp_ml(where=(Descr='-2 Log Likelihood'));
run;

 /*--------------------------------------------------*/
 /*---massage the results into layout of Table 6.2---*/
data expo; set exp_ml exp_reml;
  rename Value=Exponential;
data ind;  set ind_ml ind_reml;
  rename Value=Independent;
run;
data table6_2; merge expo ind; run;

title "Table 6.2, p. 346";
proc print data=table6_2 noobs label;
  label Descr='Fit Statistic';
  format _numeric_ best4.;
  var Descr Independent Exponential;
run;
 /*--------------------------------------------------*/


data reml; 
  set est_reml(keep=Effect estimate stderr) 
      cp_reml(keep=CovParm estimate stderr);
  if (effect = 'Intercept') then CovParm='Beta0';
  else if (effect='TN') then CovParm='Beta1';
  if CovParm='SP(EXP)' then CovParm='Theta';
  else if CovParm='Residual' then CovParm='Sigma^2';
  rename CovParm=Parameter Estimate=EstREML Stderr=SEREML;
  drop effect;
run;
data ml; 
  set est_ml(keep=Effect estimate stderr) 
      cp_ml(keep=CovParm estimate stderr);
  if (effect = 'Intercept') then CovParm='Beta0';
  else if (effect='TN') then CovParm='Beta1';
  if CovParm='SP(EXP)' then CovParm='Theta';
  else if CovParm='Residual' then CovParm='Sigma^2';
  rename CovParm=Parameter Estimate=EstML StdErr=SEML;
  drop effect;
run;
data ols;
  set est_ols(keep=effect estimate stderr);
  if (Effect='Scale') then Effect = 'Sigma^2';
  else if (Effect='Intercept') then Effect='Beta0';
  else if (Effect='TN') then Effect='Beta1';
  else;
  rename effect=Parameter Estimate=EstOLS StdErr=SEOLS;
run;
proc sort data=ols;  by Parameter;
proc sort data=ml;   by Parameter;
proc sort data=reml; by Parameter;
data table6_1; 
  merge ols ml reml;
  by Parameter;
  if (Parameter='Beta0') then p=1;
  else if (Parameter='Beta1') then p=2;
  else if (Parameter='Theta') then p=3;
  else p=4;
proc sort data=table6_1; by p;
run;

title 'Table 6.1, p. 324';
proc print data=table6_1 noobs;
  format _numeric_ best6.;
  var Parameter EstOLS SEOLS EstREML SEREML EstML SEML;
run;
 /*--------------------------------------------------*/

