
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

%include "&progdir\CNRatioData.sas";

 /*------------------------------------------------------------*/
 /*---Semivariograms of various residuals, displayed on p.313--*/
 /*------------------------------------------------------------*/


 /*---------------------------------------------*/
 /*---OLS raw and studentized residuals      ---*/
 /*---------------------------------------------*/
proc glm data=CNratio;
   model TC = TN;
   output out=olsresid residual=residual student=student;
run;

 /*---------------------------------------------*/
 /*---BLUS and recursive residuals           ---*/
 /*---------------------------------------------*/
proc autoreg data=CNratio;
  model tc = tn;
  output out=resids blus=blus recres=recres;
run;

 /*---------------------------------------------*/
 /*---Compute the semivariograms             ---*/
 /*---------------------------------------------*/
%let lagd=6;
%let maxlag=35;
proc variogram data=resids outvar=svar1;
  compute lagdistance=&lagd. maxlag=&maxlag.;
  coordinates xcoord=x ycoord=y;
  var blus;
run;
proc variogram data=resids outvar=svar2;
  compute lagdistance=&lagd. maxlag=&maxlag.;
  coordinates xcoord=x ycoord=y;
  var recres;
run;
proc variogram data=olsresid outvar=svar3;
  compute lagdistance=&lagd. maxlag=&maxlag.;
  coordinates xcoord=x ycoord=y;
  var residual;
run;
proc variogram data=olsresid outvar=svar4;
  compute lagdistance=&lagd. maxlag=&maxlag.;
  coordinates xcoord=x ycoord=y;
  var student;
run;
data plotthis;
  merge svar1(rename=(variog=blus    distance=distblus))
        svar2(rename=(variog=recres  distance=distrec ))
        svar3(rename=(variog=OLSres  distance=distols ))
        svar4(rename=(variog=student distance=diststud));
  label blus     = 'Semivariance'
        recres   = 'Semivariance'
        OLSRes   = 'Semivariance'
		student  = 'Semivariance'
		distblus = 'Distance'
		distrec  = 'Distance'
		distOLS  = 'Distance'
		diststud = 'Distance';
run;

 /*------------------------------------------------------*/
 /*---This template code is specific for SAS 9.1      ---*/
 /*---ODS graphics are experimental in SAS 9.1 and the---*/
 /*---template syntax is different in subsequent releases*/ 
 /*------------------------------------------------------*/
proc template;
   define statgraph semipanel;
      layout lattice / rows=2 columns=2;
	      layout lattice / rows=1 columns=1;
               sidebar / align=top;
                 layout overlay / padbottom=5;
                    entrytitle "Best Linear Unbiased Scales";
                 endlayout;
               endsidebar;
			   scatterplot y=blus x=distblus / 
			          xaxisopts=(ticks=(0 100 200))
                      markersymbol=circlefilled
					  markersize  = 8;
		  endlayout;
	      layout lattice / rows=1 columns=1;                                      
               sidebar / align=top;
                 layout overlay / padbottom=5;                                     
                    entrytitle "Recursive Residuals";
                 endlayout;
               endsidebar;
			   scatterplot y=recres x=distrec / 
			          xaxisopts=(ticks=(0 100 200))
                      markersymbol=circlefilled
					  markersize  = 8;
		  endlayout;
	      layout lattice / rows=1 columns=1;                                      
               sidebar / align=top;
                 layout overlay / padbottom=5;                                     
                    entrytitle "Studentized Residuals";
                 endlayout;
               endsidebar;
			   scatterplot y=student x=diststud / 
			          xaxisopts=(ticks=(0 100 200))
                      markersymbol=circlefilled
					  markersize  = 8;
		  endlayout;
	      layout lattice / rows=1 columns=1;                                      
               sidebar / align=top;
                 layout overlay / padbottom=5;                                     
                    entrytitle "OLS Residuals";
                 endlayout;
               endsidebar;
			   scatterplot y=OLSres x=distOLS / 
			          xaxisopts=(ticks=(0 100 200))
                      markersymbol=circlefilled
					  markersize  = 8;
		  endlayout;
	  endlayout;
     end;
run;
title;
ods html; 
data _null_;
    set plotthis;
    file print ods=(template='semipanel');
    put _ods_;
run;
ods html close;


