 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*--------------------------------------------------------*/
 /*---Analyze VA blood lead level data with various GLMs --*/
 /*---Results appear in Table 6.3, page 372             ---*/
 /*--------------------------------------------------------*/

 /*--------------------------------------------------------*/
 /*---Poisson regression with overdispersion            ---*/
 /*--------------------------------------------------------*/
title1 'Table 6.3 -- Poisson-Based Regression';
proc glimmix data=SGdata.VA2000;
   logtested72 = log(tested72);
   model elevated72 = mval1000 pov1000/ 
                    dist   = poisson 
                    offset = logtested72 
                    solution;
   random _residual_;
   ods select ParameterEstimates;
run;

 /*--------------------------------------------------------*/
 /*---Note: Proc GLIMMIX will not report a standard error -*/
 /*---      for the scale parameter in the previous model,-*/
 /*---      since the model is an overdispersed GLM.    ---*/
 /*---      To obtain a standard error, you can force a ---*/
 /*---      GLMM without correlations                   ---*/
 /*--------------------------------------------------------*/

proc glimmix data=SGdata.VA2000;
   logtested72 = log(tested72);
   model elevated72 = mval1000 pov1000/ 
                    dist   = poisson 
                    offset = logtested72 
                    solution;
   random _residual_ / type=sp(exp)(easting northing);
   /* Hold range at 0, implying no correlations */
   parms (1) (0) / hold=2;
   ods select CovParms ParameterEstimates;
run;

 /*--------------------------------------------------------*/
 /*---Binomial regression with overdispersion           ---*/
 /*--------------------------------------------------------*/
title1 'Table 6.3 -- Binomial-Based Regression';
proc glimmix data=SGdata.VA2000;
   logtested72 = log(tested72);
   model elevated72/Tested72 = mval1000 pov1000 / solution;
   random _residual_;
   ods select ParameterEstimates;
run;

