
/*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*--------------------------------------------------------*/
 /*---Analyze VA blood lead level data with various     ---*/
 /*---spatial models.                                   ---*/
 /*---Results appear in Table 6.4, page 376             ---*/
 /*--------------------------------------------------------*/

data VA;
   set SGdata.VA2000;
   logtested72 = log(tested72);
   obs         = _n_;
run;

 /*--------------------------------------------------------*/
 /*---Random Effects Model (see model description p. 374) -*/
 /*--------------------------------------------------------*/
title1 'Table 6.4 -- Random Effects Model';
proc glimmix data=VA;
   class obs;
   model elevated72 = mval1000 pov1000 / 
                      ddfm   = residual
	                  dist   = poisson
	                  offset = logtested72
                      solution;
   random obs;
   random _residual_;
   ods select CovParms ParameterEstimates;
   nloptions tech=nrridg;	  
run;

 /*---Here are the equivalent statements for the %GLIMMIX macro---*/
 /*
%include "&macrodir\glmm800.sas" / nosource;
%glimmix(data=VA,
   procopt=covtest,
   stmts=%str(
      class obs;
      model elevated72 = mval1000 pov1000 / solution ddfm=res;
      random obs;
	  parms (.5) (0.01 to 2.1 by .10)/; 
      id elevated72 mval1000 pov1000 easting northing logtested72;
   ),
   error=poisson,
   offset=logtested72
)
run;
 */

 /*--------------------------------------------------------*/
 /*--Conditional Spatial GLMM (see model description p. 374)*/
 /*--------------------------------------------------------*/
title1 'Table 6.4 -- Conditional Spatial GLMM';
libname outdir "&datadir";
proc glimmix data=VA;
   class obs;
   model elevated72 = mval1000 pov1000 / 
                       ddfm   = residual
	                   dist   = poisson
                       offset = logtested72
                       solution;
   random obs / type=sp(sph)(easting northing);
   random _residual_;
   parms (1) (50) (1); 
   ods select CovParms ParameterEstimates;
   nloptions tech=nrridg;	  
   output out=outdir.CGLMMpred pred(blup ilink)=condpred;
run;
data outdir.CGLMMpred; set outdir.CGLMMpred;
   condpredpct = (condpred/tested72)*100;
run;

 /*---Here are the equivalent statements for the %GLIMMIX macro---*/
 /*
%glimmix(data=VA,
   procopt=covtest,
   stmts=%str(
      class obs;
      model elevated72 = mval1000 pov1000 / solution ddfm=res;
      random obs / subject=intercept type=sp(sph)(easting northing);
      parms (1) (50) (1)/; 
      id elevated72 mval1000 pov1000 easting northing logtested72;
   ),
   error=poisson,
   offset=logtested72
);
run;
*/

 /*--------------------------------------------------------*/
 /*---Marginal Spatial GLM (see model description p. 375)--*/
 /*---Note that because a residual scale parameter is pro- */
 /*---filed by default, the covariance parameter named  ---*/
 /*---"Residual (VC)" represents the nugget effect.     ---*/
 /*--------------------------------------------------------*/
title1 'Table 6.4 -- Marginal Spatial GLM';
proc glimmix data=VA;
   model elevated72 = mval1000 pov1000 / 
                        ddfm   = residual
                        dist   = poisson
                        offset = logtested72
                        solution;
   random _residual_ / subject = intercept 
                       type    = sp(sph)(easting northing);
   random _residual_;
   parms (180) (1) (1);
   ods select CovParms ParameterEstimates;
   nloptions tech=nrridg;
run;

 /*---Note: See program VA_MargPred.sas for how to compute---*/
 /*---      spatial predictions in marginal spatial GLM   ---*/
 /*---      models.                                       ---*/

 /*---Here are the equivalent statements for the %GLIMMIX macro---*/
 /*---Note that the order of the covariance parameters is diff- --*/
 /*---erent in the GLIMMIX procedure, because it uses two R-side--*/
 /*---statements to achieve the spatial correlation with nugget---*/
 /*
%glimmix(data=VA,
   procopt=covtest,
   stmts=%str(
      model elevated72 = mval1000 pov1000 / solution ddfm=res;
      repeated / subject=intercept type=sp(sph)(easting northing) local;
	  parms (1) (180) (1); 
      id elevated72 mval1000 pov1000 easting northing logtested72;
   ),
   error=poisson,
   offset=logtested72
)
run;
*/
