
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*---------------------------------------------------*/
 /*---Computation of predictions in spatial marginal--*/
 /*---GLM with correlations.                       ---*/
 /*---Predictors are computed according to (6.87)  ---*/
 /*---and (6.90).                                  ---*/
 /*---------------------------------------------------*/

data VA;
  set SGdata.VA2000;
  logtested72 = log(tested72);
run;
 /*---data set with prediction locations. We use the--*/
 /*---observed locations in this example.          ---*/
data predloc; set VA; elevated72=.; run;


title1 'Table 6.4, p. 376 -- Marginal Spatial GLM';
proc glimmix data=VA;
   model elevated72 = mval1000 pov1000 / 
                        ddfm   = residual
                        dist   = poisson
                        offset = logtested72
                        solution;
   random _residual_ / subject = intercept 
                       type    = sp(sph)(easting northing);
   random _residual_;
   parms (180) (1) (1);
   ods select CovParms ParameterEstimates;
   nloptions tech=nrridg;
   ods output CovParms=cp ParameterEstimates=ests;
run;

proc iml; 
  /*--the observed data---*/
  use VA; read all var{mval1000 pov1000} into x;
		  read all var{logtested72}      into offset1;
		  read all var{elevated72}       into y;
		  read all var{easting northing} into s1;
  close VA;
  use ests;read all var{Estimate} into betahat; close ests;
  use cp;  read all var{Estimate} into thetahat;close cp;
  nw = nrow(x);
  X1 = J(nw,1,1) || X;
  p  = ncol(X);
  /*---the predciction locations---*/
  use predloc; read all var{mval1000 pov1000} into x0;
		   read all var{logtested72}      into offset0;
		   read all var{tested72}         into count;
		   read all var{easting northing} into s0;
  close predloc;
  k        = nrow(x0);
  X0       = J(k,1,1) || X0;
  s        = s1 // s0;
  rho      = thetahat[1];
  sigma2   = thetahat[3];
  c0       = thetahat[2];
  muhat1   = exp(offset1 + X1*betahat);
  muhat0   = exp(offset0 + X0*betahat);
  muhat    = muhat1 // muhat0;
  n        = nrow(muhat);
  deltavmu = diag(sqrt(1/muhat));
  zstar    = (Y-muhat1)/muhat1 + X1*Betahat; 

  dist=J(n,n,0);
  do I=1 to n-1;
    do J=I+1 to n;
      dist[I,J] = sqrt( (s[i,1]-s[j,1])##2 + (s[i,2]-s[j,2])##2);
    end;
  end;
  /*---construct the correlation matrix (spherical model)---*/
  dist = dist + dist`;
  R = J(n,n,0);
  do i=1 to n;
     do j=1 to n;
	 d = dist[i,j];
	 if (d < rho) then R[i,j] = 1 - 1.5 # d/rho + 0.5# ((d/rho)##3);
     end;
  end;
  /*---Predict at the prediction locations---*/
  Sigmamu = deltavmu*(c0#I(n) + sigma2#R)*deltavmu;
  VZZ     = Sigmamu[1:nw, 1:nw];
  VZ0     = Sigmamu[nw+1:nw+K,1:nw];
  V00     = Sigmamu[nw+1:nw+K, nw+1:nw+K];
  pred0   = X0*betahat + VZ0*Inv(VZZ) * (zstar-X1*betahat);
  /*---Z_6_87 is predictor (6.87) on page 369---*/
  Z_6_87 = exp(pred0+offset0);
  /*---y0 is predictor (6.90) on page 370---*/
  y0      = muhat0 + (pred0 - x0*betahat)#muhat0;
  y0pct   = (y0/exp(offset0))*100;
  names = {"margfit","margpct"};
  result = y0 || y0pct;
  create predvals from result[colname=names];
  append from result;
  close result;
quit;

libname outdir "&datadir";
data outdir.MArgpred; 
  merge VA predvals; 
run;
