
 /*-------------------------------------------------------------------------*/
 /*---Schabenberger, O. and Gotway, C. A. (2005), "Statistical Methods for--*/
 /*---Spatial Data Analysis", Boca Raton, FL, CRC Press, Chapman & Hall  ---*/
 /*-------------------------------------------------------------------------*/

 /*-----------------------------------------------------------*/
 /*---You need to run the programs that compute the various---*/
 /*---predictions first:                                   ---*/
 /*---    VA_CAR (Example 1.4, Tabe 6.5).sas               ---*/
 /*---    VA_GLMM (Example 1.4, Table 6.4).sas             ---*/
 /*---    VA_MargPred.sas                                  ---*/
 /*-----------------------------------------------------------*/

libname outdir "&datadir";

proc sort data=outdir.Carpred   out=Carpred;   by fips;
proc sort data=outdir.Margpred  out=Margpred;  by fips;
proc sort data=outdir.CGLMMpred out=CGLMMpred; by fips;
run;

goptions hsize=8in vsize=8in;
symbol1 color=black value=dot  height=0.175in;
symbol2 color=black value=none i=join l=1;

 /*----------------------------------------------*/
 /*---Figure 6.10                             ---*/
axis1 minor=none
      order=(-5 to 55 by 10)
	  label=(font='Arial' Height=1.5 angle=90 
             'Marginal Spatial GLM Predictions')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);
axis2 minor=none
      order=(0 to 60 by 10)
	  label=(font='Arial' Height=1.5 
            'Conditional Spatial GLMM Predictions')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);

data refline;
  input x y;
  datalines;
0 0
50 50
;
data plotthis;
  merge MargPred(keep=margpct) 
        CGLMMPred(keep=condpredpct)
		refline;
run;
title;
proc gplot data=plotthis;
   plot margpct*condpredpct=1 
        y*x=2 
        / overlay vaxis=axis1 haxis=axis2;
run;
quit;
 /*----------------------------------------------*/


 /*----------------------------------------------*/
 /*---Figure 6.11                             ---*/
axis1 minor=none
      order=(-5 to 55 by 10)
	  label=(font='Arial' Height=1.5 angle=90 
             'Marginal Model with Geostatistical Variance')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);
axis2 minor=none
      order=(0 to 50 by 10)
	  label=(font='Arial' Height=1.5 
            'Marginal Model with CAR Variance')
      offset=(0.5in,0.5in)
	  value=(font='Arial' Height=1.3);
data plotthis;
  merge MargPred(keep=margpct) 
        CARPred(keep=mcarnuggetfitpct)
		refline;
run;
proc gplot data=plotthis;
   plot margpct*mcarnuggetfitpct=1 
        y*x=2 / overlay vaxis=axis1 haxis=axis2;
run;
quit;
 /*----------------------------------------------*/
