/* DISCLAIMER                                                   
 -----------                                                  
                                                              
 THIS INFORMATION IS PROVIDED "AS IS".
 THERE ARE NO WARRANTIES, EXPRESSED OR IMPLIED, AS TO 
 MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE REGARDING 
 THE ACCURACY OF THE MATERIALS OR CODE CONTAINED HEREIN.   
*/
/* --------------------------------------------------- */
/* A SAS macro to generate binary weight matrices      */
/* on a regular &rows * &cols lattice.                 */
/* Arguments: rows= # of rows                          */
/*            cols= # no of columns                    */
/*            move= type of move (rook, bishop, queen) */
/*            out= name of output data set             */
/* The default output data set is w_data and can serve */
/* as one of the input data sets for the %MoranI macro */
/* --------------------------------------------------- */


%macro ContWght(rows=4,cols=5,move=rook,out=w_data);
  proc iml;
    reset noprint fw=4;
    n   = &rows*&cols;
    W   = J(n,n,0);
      %if %index(%Upcase(&move),ROOK) %then %do;
        pos = J(4,1,0);
        /* neighbors to the right and left + neighbors above and below */
        pos    = J(4,1,0);
        do i = 1 to &rows; do j = 1 to &cols;
          pos[1] = (j > 1)*((i-1)*&cols. + (j-1));
	  pos[2] = (i < &rows.)*(i*&cols.     + j);
	  pos[3] = (j < &cols.)*((i-1)*&cols.+ (j+1));
	  pos[4] = (i > 1)*((i-2)*&cols. + j); 
          do k=1 to 4; 
             if (pos[k] > 0) then W[(i-1)*&cols. + j,pos[k]] = 1;
          end;
        end; end;
      %end;
      %if %index(%Upcase(&move),BISHOP) %then %do;
        /* neighbors on diagonal           */
        pos    = J(4,1,0);
        do i = 1 to &rows; do j = 1 to &cols;
      	  pos[1] = (i > 1)*(j > 1)*((i-2)*&cols. + (j-1));
          pos[2] = (i < &rows.)*(j > 1)*((i*&cols.)   + (j-1));
          pos[3] = (i < &rows.)*(j < &cols.)*((i*&cols.)   + (j+1));
          pos[4] = (i > 1)*(j < &cols.)*((i-2)*&cols. + (j+1));
          do k=1 to 4; 
             if (pos[k] > 0) then W[(i-1)*&cols. + j,pos[k]] = 1;
          end;
        end; end;
      %end;
      %if %index(%Upcase(&move),QUEEN) %then %do;
        pos    = J(8,1,0);
        do i = 1 to &rows; do j = 1 to &cols;     
          pos[1] = (j > 1)*((i-1)*&cols. + (j-1));
          pos[2] = (i < &rows.)*(i*&cols.     + j);
          pos[3] = (j < &cols.)*((i-1)*&cols.+ (j+1));
          pos[4] = (i > 1)*((i-2)*&cols. + j); 
      	  pos[5] = (i > 1)*(j > 1)*((i-2)*&cols. + (j-1));
          pos[6] = (i < &rows.)*(j > 1)*((i*&cols.)   + (j-1));
          pos[7] = (i < &rows.)*(j < &cols.)*((i*&cols.)   + (j+1));
          pos[8] = (i > 1)*(j < &cols.)*((i-2)*&cols. + (j+1));
          do k=1 to 8; 
             if (pos[k] > 0) then W[(i-1)*&cols. + j,pos[k]] = 1;
          end;
        end; end;
      %end;
  create &out from w; append from w; close &out;
  *  print w;
  quit;
%mend ContWght;

